==> owncloud-9.0.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_external/l10n/sv.js <==
OC.L10N.register(
    "files_external",
    {
    "Step 1 failed. Exception: %s" : "Steg 1 flaerade. Undantag: %s",
    "Step 2 failed. Exception: %s" : "Steg 2 falerade. Undantag: %s",
    "External storage" : "Extern lagring",
    "Invalid mount point" : "Ogiltig monteringspunkt",
    "Insufficient data: %s" : "Otillräcklig data: %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "Lagring med id \"%i\" är inte redigerbar av användare",
    "Personal" : "Personligt",
    "System" : "System",
    "Grant access" : "Bevilja åtkomst",
    "Access granted" : "Åtkomst beviljad",
    "Generate keys" : "Generera nycklar",
    "Error generating key pair" : "Fel vid generering av nyckelpar",
    "Enable encryption" : "Aktivera kryptering",
    "Enable previews" : "Aktivera förhandsgranskningar",
    "Enable sharing" : "Aktivera delning",
    "Check for changes" : "Sök efter ändringar",
    "Never" : "Aldrig",
    "All users. Type to select user or group." : "Alla användare. Skriv för att välja användare eller grupp.",
    "(group)" : "(grupp)",
    "Admin defined" : "Admin definerad",
    "Saved" : "Sparad",
    "Empty response from the server" : "Tomt svar från servern",
    "Couldn't get the list of external mount points: {type}" : "Kunde inte hämta listan för externa monteringspunkter: {type}",
    "There was an error with message: " : "Det fanns ett fel med meddelande:",
    "External mount error" : "Fel vid extern montering",
    "external-storage" : "extern-lagring",
    "Username" : "Användarnamn",
    "Password" : "Lösenord",
    "Credentials saved" : "Sparade referenser",
    "Credentials saving failed" : "Misslyckades med att spara referenser",
    "Credentials required" : "Referenser krävs",
    "Save" : "Spara",
    "Access key" : "Åtkomstnyckel",
    "Secret key" : "Hemlig nyckel",
    "Builtin" : "Inbyggt",
    "None" : "Ingen",
    "OAuth1" : "OAuth1",
    "App key" : "App-nyckel",
    "App secret" : "App-hemlighet",
    "OAuth2" : "OAuth2",
    "Client ID" : "Klient ID",
    "Client secret" : "klient secret",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Namn på arrendator",
    "API key" : "API-nyckel",
    "Username and password" : "Användarnamn och lösenord",
    "Log-in credentials, save in session" : "Inloggninguppgifter, spara i sessionen",
    "Public key" : "Publik nyckel",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Värdnamn",
    "Port" : "Port",
    "Region" : "Län",
    "Enable SSL" : "Aktivera SSL",
    "Enable Path Style" : "Aktivera Path Style",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Fjärrmapp",
    "Secure https://" : "Säker https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Server",
    "Secure ftps://" : "Säker ftps://",
    "Google Drive" : "Google Drive",
    "Local" : "Lokal",
    "Location" : "Plats",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP-inloggning med hemlig nyckel",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Dela",
    "Domain" : "Domän",
    "SMB / CIFS using OC login" : "SMB / CIFS använder OC inloggning",
    "Username as share" : "Användarnamn till utdelning",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Namn på tjänst",
    "<b>Note:</b> " : "<b> OBS: </ b>",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b> OBS: </ b> cURL-stöd i PHP inte är aktiverat eller installerat. Montering av %s är inte möjlig. Be din systemadministratör att installera det.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b> OBS: </ b> FTP-stödet i PHP inte är aktiverat eller installerat. Montering av %s är inte möjlig. Be din systemadministratör att installera det.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b> OBS: </ b> \"%s\" är inte installerat. Montering av %s är inte möjlig. Be din systemadministratör att installera det.",
    "No external storage configured" : "Ingen extern lagring konfigurerad",
    "You can add external storages in the personal settings" : "Du kan lägga till externa lagringar i de personliga inställningarna",
    "Name" : "Namn",
    "Storage type" : "Lagringstyp",
    "Scope" : "Scope",
    "External Storage" : "Extern lagring",
    "Folder name" : "Mappnamn",
    "Authentication" : "Autentisering",
    "Configuration" : "Konfiguration",
    "Available for" : "Tillgänglig för",
    "Add storage" : "Lägg till lagring",
    "Advanced settings" : "Avancerade inställningar",
    "Delete" : "Radera",
    "Allow users to mount external storage" : "Tillåt användare att montera extern lagring",
    "Allow users to mount the following external storage" : "Tillåt användare att montera följande extern lagring",
    "SMB / CIFS" : "SMB / CIFS"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.1.3-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_external/l10n/sv.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Fel vid hämtning av åtkomst-token. Verifiera att din app-nyckel och hemlighet stämmer.",
    "Step 1 failed. Exception: %s" : "Steg 1 flaerade. Undantag: %s",
    "Step 2 failed. Exception: %s" : "Steg 2 falerade. Undantag: %s",
    "External storage" : "Extern lagring",
    "Personal" : "Personligt",
    "System" : "System",
    "Grant access" : "Bevilja åtkomst",
    "Generate keys" : "Generera nycklar",
    "Error generating key pair" : "Fel vid generering av nyckelpar",
    "All users. Type to select user or group." : "Alla användare. Skriv för att välja användare eller grupp.",
    "(group)" : "(grupp)",
    "Admin defined" : "Admin definerad",
    "Saved" : "Sparad",
    "Empty response from the server" : "Tomt svar från servern",
    "Couldn't get the list of external mount points: {type}" : "Kunde inte hämta listan för externa monteringspunkter: {type}",
    "There was an error with message: " : "Det fanns ett fel med meddelande:",
    "External mount error" : "Fel vid extern montering",
    "external-storage" : "extern-lagring",
    "Username" : "Användarnamn",
    "Password" : "Lösenord",
    "Credentials saved" : "Sparade referenser",
    "Credentials saving failed" : "Misslyckades med att spara referenser",
    "Credentials required" : "Referenser krävs",
    "Save" : "Spara",
    "Invalid mount point" : "Ogiltig monteringspunkt",
    "Insufficient data: %s" : "Otillräcklig data: %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "Lagring med id \"%i\" är inte redigerbar av användare",
    "Access key" : "Åtkomstnyckel",
    "Secret key" : "Hemlig nyckel",
    "Builtin" : "Inbyggt",
    "None" : "Ingen",
    "OAuth1" : "OAuth1",
    "App key" : "App-nyckel",
    "App secret" : "App-hemlighet",
    "OAuth2" : "OAuth2",
    "Client ID" : "Klient ID",
    "Client secret" : "klient secret",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Namn på arrendator",
    "API key" : "API-nyckel",
    "Username and password" : "Användarnamn och lösenord",
    "Log-in credentials, save in session" : "Inloggninguppgifter, spara i sessionen",
    "Public key" : "Publik nyckel",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Värdnamn",
    "Port" : "Port",
    "Region" : "Län",
    "Enable SSL" : "Aktivera SSL",
    "Enable Path Style" : "Aktivera Path Style",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Fjärrmapp",
    "Secure https://" : "Säker https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Server",
    "Secure ftps://" : "Säker ftps://",
    "Google Drive" : "Google Drive",
    "Local" : "Lokal",
    "Location" : "Plats",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP-inloggning med hemlig nyckel",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Dela",
    "Domain" : "Domän",
    "SMB / CIFS using OC login" : "SMB / CIFS använder OC inloggning",
    "Username as share" : "Användarnamn till utdelning",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Namn på tjänst",
    "<b>Note:</b> " : "<b> OBS: </ b>",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b> OBS: </ b> cURL-stöd i PHP inte är aktiverat eller installerat. Montering av %s är inte möjlig. Be din systemadministratör att installera det.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b> OBS: </ b> FTP-stödet i PHP inte är aktiverat eller installerat. Montering av %s är inte möjlig. Be din systemadministratör att installera det.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b> OBS: </ b> \"%s\" är inte installerat. Montering av %s är inte möjlig. Be din systemadministratör att installera det.",
    "No external storage configured" : "Ingen extern lagring konfigurerad",
    "You can add external storages in the personal settings" : "Du kan lägga till externa lagringar i de personliga inställningarna",
    "Name" : "Namn",
    "Storage type" : "Lagringstyp",
    "Scope" : "Scope",
    "Enable encryption" : "Aktivera kryptering",
    "Enable previews" : "Aktivera förhandsgranskningar",
    "Enable sharing" : "Aktivera delning",
    "Check for changes" : "Sök efter ändringar",
    "Never" : "Aldrig",
    "External Storage" : "Extern lagring",
    "Folder name" : "Mappnamn",
    "Authentication" : "Autentisering",
    "Configuration" : "Konfiguration",
    "Available for" : "Tillgänglig för",
    "Add storage" : "Lägg till lagring",
    "Advanced settings" : "Avancerade inställningar",
    "Delete" : "Radera",
    "Allow users to mount external storage" : "Tillåt användare att montera extern lagring",
    "Allow users to mount the following external storage" : "Tillåt användare att montera följande extern lagring"
},
"nplurals=2; plural=(n != 1);");
